==> haskell-profunctors-5.4-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.4
id: profunctors-5.4-IdYrTUicB7SfmM4KQ85o3
key: profunctors-5.4-IdYrTUicB7SfmM4KQ85o3
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors.
category: Control, Categories
abi: b273b7a55d0395d61f805b562c86085e
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
import-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/profunctors-5.4
hs-libraries: HSprofunctors-5.4-IdYrTUicB7SfmM4KQ85o3
depends:
    base-4.12.0.0 base-orphans-0.8.1-1eiH9qVb6AAEHB9dzgavFy
    bifunctors-5.5.4-F7d4B9ltNTgBiYmBPi0jgL
    comonad-5.0.5-Jl6mV4tCv8DH0upvqmXcGR
    contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
    distributive-0.6-GG50drgnUvrA8VTISpGDag
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.4-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.4
id: profunctors-5.4-LjWaJA8kJzmIr0eJAafd3B
key: profunctors-5.4-LjWaJA8kJzmIr0eJAafd3B
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors.
category: Control, Categories
abi: f88dbd4dc89d96605640fa210cd99226
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
import-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/profunctors-5.4
hs-libraries: HSprofunctors-5.4-LjWaJA8kJzmIr0eJAafd3B
depends:
    base-4.12.0.0 base-orphans-0.8.1-1eiH9qVb6AAEHB9dzgavFy
    bifunctors-5.5.4-F7d4B9ltNTgBiYmBPi0jgL
    comonad-5.0.5-Jl6mV4tCv8DH0upvqmXcGR
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    distributive-0.6-GG50drgnUvrA8VTISpGDag
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
